pub struct CompileCommand {
pub directory: Utf8PathBuf,
pub file: Utf8PathBuf,
pub arguments: Vec<String>,
pub output: Utf8PathBuf,
}Expand description
One entry of a Clang JSON Compilation Database.
arguments is kept as a list so each backend / consumer can render it
however the format requires (LLVM accepts both command and
arguments keys; cabin-ninja emits command).
Fields
directory: Utf8PathBuffile: Utf8PathBufarguments: Vec<String>output: Utf8PathBufTrait Implementations
Sourceimpl Clone for CompileCommand
impl Clone for CompileCommand
Sourcefn clone(&self) -> CompileCommand
fn clone(&self) -> CompileCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompileCommand
impl Debug for CompileCommand
impl Eq for CompileCommand
Sourceimpl PartialEq for CompileCommand
impl PartialEq for CompileCommand
Sourcefn eq(&self, other: &CompileCommand) -> bool
fn eq(&self, other: &CompileCommand) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompileCommand