CleanRequest

Struct CleanRequest 

pub struct CleanRequest<'a> {
    pub build_dir: &'a Path,
    pub workspace_root: &'a Path,
    pub package_roots: &'a [PathBuf],
    pub protected_source_paths: &'a [PathBuf],
    pub scope: CleanScope,
}
Inputs to plan_clean.

Fields

build_dir: &'a Path

Resolved absolute build directory.

workspace_root: &'a Path

Workspace root directory (manifest’s parent). Used by the safety check that refuses to clean the workspace itself.

package_roots: &'a [PathBuf]

Manifest directories of every loaded package - single package or every workspace member. Used to refuse a build directory that points at a package source tree.

protected_source_paths: &'a [PathBuf]

Source files and source-owned directories that must not be contained by the build directory. This lets in-tree build dirs like <pkg>/build keep working while rejecting dangerous settings such as --build-dir src.

scope: CleanScope

What to clean.