BuildGraph

Struct BuildGraph 

pub struct BuildGraph {
    pub actions: Vec<Action>,
    pub default_outputs: Vec<PathBuf>,
    pub compile_commands: Vec<CompileCommand>,
}
Backend-independent description of everything that needs to happen to realize a build. A backend (currently cabin-ninja) walks this graph and emits the equivalent build-system-specific representation.

Fields

actions: Vec<Action>

All actions to execute, in topological order. Earlier actions in the vector never depend on later actions.

default_outputs: Vec<PathBuf>

Output paths that should be marked as default targets.

compile_commands: Vec<CompileCommand>

One entry per C/C++ source compile, used to emit compile_commands.json. Both languages contribute entries with their language-appropriate compiler driver and flags recorded in arguments.