CompileCommand

Struct CompileCommand 

pub struct CompileCommand {
    pub directory: PathBuf,
    pub file: PathBuf,
    pub arguments: Vec<String>,
    pub output: PathBuf,
}
One entry of a Clang JSON Compilation Database.

arguments is kept as a list so each backend / consumer can render it however the format requires (LLVM accepts both command and arguments keys; cabin-ninja emits command).

Fields

directory: PathBuffile: PathBufarguments: Vec<String>output: PathBuf